@@ -11,27 +11,20 @@ set.seed (1)
 
 
 ###################################################
-### code chunk number 2: bivariate.Rnw:101-104
+### code chunk number 2: bivariate.Rnw:101-103
 ###################################################
-library (intoo)
 library (barsurf)
 library (bivariate)
 
 
 ###################################################
-### code chunk number 3: bivariate.Rnw:114-115
+### code chunk number 3: bivariate.Rnw:113-114
 ###################################################
-set.bs.options (nhl=0, ref.arrows=FALSE, rendering.style="pdf")
+set.bs.options (nhl=0, rendering.style="pdf", theme="gold", ref.arrows=FALSE)
 
 
 ###################################################
-### code chunk number 4: bivariate.Rnw:123-124
-###################################################
-set.bs.theme ("gold")
-
-
-###################################################
-### code chunk number 5: bivariate.Rnw:142-148
+### code chunk number 4: bivariate.Rnw:139-145
 ###################################################
 f <- dubvpmf (
     1, 6, #first variable
@@ -42,28 +35,28 @@ F <- dubvcdf (
 
 
 ###################################################
-### code chunk number 6: bivariate.Rnw:154-155
+### code chunk number 5: bivariate.Rnw:151-152
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot (f)
 
 
 ###################################################
-### code chunk number 7: bivariate.Rnw:157-158
+### code chunk number 6: bivariate.Rnw:154-155
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot (F)
 
 
 ###################################################
-### code chunk number 8: bivariate.Rnw:166-168
+### code chunk number 7: bivariate.Rnw:163-165
 ###################################################
 f (2, 4)
 F (2, 4)
 
 
 ###################################################
-### code chunk number 9: bivariate.Rnw:176-180
+### code chunk number 8: bivariate.Rnw:173-177
 ###################################################
 d.unif.pmf.eval <- function (x, a, b)    #x ignored
     1 / (b - a + 1)
@@ -72,80 +65,62 @@ d.unif.cdf.eval <- function (x, a, b)    #x used
 
 
 ###################################################
-### code chunk number 10: bivariate.Rnw:183-185
+### code chunk number 9: bivariate.Rnw:180-182
 ###################################################
 d.unif.pmf.eval (2, 1, 6) * d.unif.pmf.eval (4, 1, 6)
 d.unif.cdf.eval (2, 1, 6) * d.unif.cdf.eval (4, 1, 6)
 
 
 ###################################################
-### code chunk number 11: bivariate.Rnw:209-211
+### code chunk number 10: bivariate.Rnw:206-208
 ###################################################
 f <- bnbvpmf (0.5, 0.5, 10)
 F <- bnbvcdf (0.5, 0.5, 10)
 
 
 ###################################################
-### code chunk number 12: bivariate.Rnw:217-218
+### code chunk number 11: bivariate.Rnw:214-215
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot (f)
 
 
 ###################################################
-### code chunk number 13: bivariate.Rnw:220-221
-###################################################
-set.bs.options (nhl=0, ref.arrows=FALSE, rendering.style="pdf", main="gpd.litmus.fit")
-
-
-###################################################
-### code chunk number 14: bivariate.Rnw:223-224
+### code chunk number 12: bivariate.Rnw:217-218
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot (f, FALSE)
 
 
 ###################################################
-### code chunk number 15: bivariate.Rnw:226-227
-###################################################
-set.bs.theme ("gold")
-
-
-###################################################
-### code chunk number 16: bivariate.Rnw:233-234
+### code chunk number 13: bivariate.Rnw:223-224
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot (F)
 
 
 ###################################################
-### code chunk number 17: bivariate.Rnw:245-246
-###################################################
-set.bs.theme ("blue")
-
-
-###################################################
-### code chunk number 18: bivariate.Rnw:271-272
+### code chunk number 14: bivariate.Rnw:257-258
 ###################################################
 f <- pbvpmf.2 (8, 8, 2)
 
 
 ###################################################
-### code chunk number 19: bivariate.Rnw:278-279
+### code chunk number 15: bivariate.Rnw:264-265
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (f)
+plot (f, theme="blue")
 
 
 ###################################################
-### code chunk number 20: bivariate.Rnw:281-282
+### code chunk number 16: bivariate.Rnw:267-268
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (f, FALSE)
+plot (f, FALSE, theme="blue")
 
 
 ###################################################
-### code chunk number 21: bivariate.Rnw:296-299
+### code chunk number 17: bivariate.Rnw:282-285
 ###################################################
 h <- matrix (sample (1:24), 4, 6)
 rownames (h) <- LETTERS [1:4]
@@ -153,60 +128,54 @@ colnames (h) <- letters [1:6]
 
 
 ###################################################
-### code chunk number 22: bivariate.Rnw:302-303
+### code chunk number 18: bivariate.Rnw:288-289
 ###################################################
 h
 
 
 ###################################################
-### code chunk number 23: bivariate.Rnw:306-307
+### code chunk number 19: bivariate.Rnw:292-293
 ###################################################
 f <- gbvpmf (h)
 
 
 ###################################################
-### code chunk number 24: bivariate.Rnw:313-314 (eval = FALSE)
+### code chunk number 20: bivariate.Rnw:299-300 (eval = FALSE)
 ###################################################
-## plot (f, FALSE)
+## plot (f, FALSE, theme="blue")
 
 
 ###################################################
-### code chunk number 25: bivariate.Rnw:316-319
+### code chunk number 21: bivariate.Rnw:302-305
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 p0 <- matrix.margins ()
-plot (f, FALSE)
+plot (f, FALSE, theme="blue")
 par (p0)
 
 
 ###################################################
-### code chunk number 26: bivariate.Rnw:321-322
+### code chunk number 22: bivariate.Rnw:307-308
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (f)
+plot (f, theme="blue")
 
 
 ###################################################
-### code chunk number 27: bivariate.Rnw:330-331
+### code chunk number 23: bivariate.Rnw:316-317
 ###################################################
 h [2, 4] / sum (h)
 
 
 ###################################################
-### code chunk number 28: bivariate.Rnw:334-336
+### code chunk number 24: bivariate.Rnw:320-322
 ###################################################
 f (2, 4)
 f ("B", "d")
 
 
 ###################################################
-### code chunk number 29: bivariate.Rnw:344-345
-###################################################
-set.bs.theme ("gold")
-
-
-###################################################
-### code chunk number 30: bivariate.Rnw:355-361
+### code chunk number 25: bivariate.Rnw:337-343
 ###################################################
 f <- cubvpdf (
     0, 2, #first variable
@@ -217,163 +186,158 @@ F <- cubvcdf (
 
 
 ###################################################
-### code chunk number 31: bivariate.Rnw:367-368
+### code chunk number 26: bivariate.Rnw:349-350
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot (f)
 
 
 ###################################################
-### code chunk number 32: bivariate.Rnw:370-371
+### code chunk number 27: bivariate.Rnw:352-353
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot (F)
 
 
 ###################################################
-### code chunk number 33: bivariate.Rnw:378-379
-###################################################
-set.bs.theme ("blue")
-
-
-###################################################
-### code chunk number 34: bivariate.Rnw:391-393
+### code chunk number 28: bivariate.Rnw:369-371
 ###################################################
 f <- nbvpdf (0, 0, 1, 1, 0)
 F <- nbvcdf (0, 0, 1, 1, 0)
 
 
 ###################################################
-### code chunk number 35: bivariate.Rnw:400-401
+### code chunk number 29: bivariate.Rnw:378-379
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (f)
+plot (f, theme="blue")
 
 
 ###################################################
-### code chunk number 36: bivariate.Rnw:403-404
+### code chunk number 30: bivariate.Rnw:381-382
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (f, FALSE)
+plot (f, FALSE, theme="blue")
 
 
 ###################################################
-### code chunk number 37: bivariate.Rnw:410-411
+### code chunk number 31: bivariate.Rnw:388-389
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (F)
+plot (F, theme="blue")
 
 
 ###################################################
-### code chunk number 38: bivariate.Rnw:413-414
+### code chunk number 32: bivariate.Rnw:391-392
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (F, FALSE)
+plot (F, FALSE, theme="blue")
 
 
 ###################################################
-### code chunk number 39: bivariate.Rnw:430-433
+### code chunk number 33: bivariate.Rnw:408-409
 ###################################################
-f <- bmbvpdf (
-    3.5, 0, 1, 1,    #first component distribution
-    6.5, 0, 1, 1)    #second component distribution
+f <- bmbvpdf (-1.5, 1.5)
 
 
 ###################################################
-### code chunk number 40: bivariate.Rnw:439-441
+### code chunk number 34: bivariate.Rnw:415-417
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (f,
-    axes = c (TRUE, FALSE), xat = c (3.5, 6.5) )
+plot (f, theme="blue",
+    axes = c (TRUE, FALSE), xat = c (-1.5, 1.5) )
 
 
 ###################################################
-### code chunk number 41: bivariate.Rnw:443-445
+### code chunk number 35: bivariate.Rnw:419-421
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (f, FALSE,
-    axes = c (TRUE, FALSE), xat = c (3.5, 6.5) )
+plot (f, FALSE, theme="blue",
+    axes = c (TRUE, FALSE), xat = c (-1.5, 1.5) )
 
 
 ###################################################
-### code chunk number 42: bivariate.Rnw:462-463
+### code chunk number 36: bivariate.Rnw:438-439
 ###################################################
 f <- dtvpdf (2, 4, 6)
 
 
 ###################################################
-### code chunk number 43: bivariate.Rnw:469-470
+### code chunk number 37: bivariate.Rnw:445-446
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (f)
+plot (f, theme="blue")
 
 
 ###################################################
-### code chunk number 44: bivariate.Rnw:472-473
+### code chunk number 38: bivariate.Rnw:448-449
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (f, FALSE)
+plot (f, FALSE, theme="blue")
 
 
 ###################################################
-### code chunk number 45: bivariate.Rnw:491-492
+### code chunk number 39: bivariate.Rnw:467-469
 ###################################################
 data ("geyser", package="MASS")
+names (geyser)
 
 
 ###################################################
-### code chunk number 46: bivariate.Rnw:495-498
+### code chunk number 40: bivariate.Rnw:472-473
 ###################################################
-attach (geyser)
-fh <- kbvpdf (duration, waiting, 0.7, 7)
-detach (geyser)
+fh <- kbvpdf (,,0.7, 7, data = geyser [,2:1])
 
 
 ###################################################
-### code chunk number 47: bivariate.Rnw:504-505
+### code chunk number 41: bivariate.Rnw:479-480
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (fh, FALSE)
+plot (fh, FALSE, theme="blue")
 
 
 ###################################################
-### code chunk number 48: bivariate.Rnw:511-512
+### code chunk number 42: bivariate.Rnw:486-487
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (fh)
+plot (fh, theme="blue")
 
 
 ###################################################
-### code chunk number 49: bivariate.Rnw:533-536
+### code chunk number 43: bivariate.Rnw:508-509
 ###################################################
-attach (trees)
-Fh <- ebvcdf (Height, Volume)
-detach (trees)
+names (trees)
 
 
 ###################################################
-### code chunk number 50: bivariate.Rnw:543-544
+### code chunk number 44: bivariate.Rnw:512-513
+###################################################
+Fh <- ebvcdf (data = trees [,2:3])
+
+
+###################################################
+### code chunk number 45: bivariate.Rnw:520-521
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (Fh)
+plot (Fh, theme="blue")
 
 
 ###################################################
-### code chunk number 51: bivariate.Rnw:546-547
+### code chunk number 46: bivariate.Rnw:523-524
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (Fh, FALSE)
+plot (Fh, FALSE, theme="blue")
 
 
 ###################################################
-### code chunk number 52: bivariate.Rnw:553-554
+### code chunk number 47: bivariate.Rnw:530-531
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (Fh, FALSE, reg=TRUE)
+plot (Fh, FALSE, reg=TRUE, theme="blue")
 
 
 ###################################################
-### code chunk number 53: bivariate.Rnw:604-608
+### code chunk number 48: bivariate.Rnw:579-583
 ###################################################
 f <- ntvpdf (
     0, 0, 0,      #mean: X, Y, Z
@@ -382,72 +346,66 @@ f <- ntvpdf (
 
 
 ###################################################
-### code chunk number 54: bivariate.Rnw:611-612
+### code chunk number 49: bivariate.Rnw:586-587
 ###################################################
-f %$% covariance.matrix
+f@covariance.matrix
 
 
 ###################################################
-### code chunk number 55: bivariate.Rnw:616-617
+### code chunk number 50: bivariate.Rnw:591-592
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (f)
+plot (f, theme="blue")
 
 
 ###################################################
-### code chunk number 56: bivariate.Rnw:628-629
-###################################################
-getOption("SweaveHooks")[["fig"]]()
-plot (f, FALSE)
-
-
-###################################################
-### code chunk number 57: bivariate.Rnw:636-638
+### code chunk number 51: bivariate.Rnw:605-608
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plotf_cfield (function (y, z) f (0, y, z), c (-3, 3),
+    theme="blue",
     xlab="y", ylab="z")
 
 
 ###################################################
-### code chunk number 58: bivariate.Rnw:656-658
+### code chunk number 52: bivariate.Rnw:626-628
 ###################################################
 f1 <- nbvpdf (0, 0, 1, 1, 0)
-f1 %$% covariance.matrix
+f1@covariance.matrix
 
 
 ###################################################
-### code chunk number 59: bivariate.Rnw:662-663
+### code chunk number 53: bivariate.Rnw:632-633
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (f1, all=TRUE, n=20)
+plot (f1, all=TRUE, n=20, theme="blue")
 
 
 ###################################################
-### code chunk number 60: bivariate.Rnw:670-672
+### code chunk number 54: bivariate.Rnw:640-642
 ###################################################
 f2 <- nbvpdf (0, 0, 1, 1, 0.75)
-f2 %$% covariance.matrix
+f2@covariance.matrix
 
 
 ###################################################
-### code chunk number 61: bivariate.Rnw:677-678
+### code chunk number 55: bivariate.Rnw:647-648
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (f2, all=TRUE, n=20)
+plot (f2, all=TRUE, n=20, theme="blue")
 
 
 ###################################################
-### code chunk number 62: bivariate.Rnw:684-686
+### code chunk number 56: bivariate.Rnw:654-656
 ###################################################
 f3 <- nbvpdf (0, 0, 1, 1, -0.75)
-f3 %$% covariance.matrix
+f3@covariance.matrix
 
 
 ###################################################
-### code chunk number 63: bivariate.Rnw:691-692
+### code chunk number 57: bivariate.Rnw:661-662
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-plot (f3, all=TRUE, n=20)
+plot (f3, all=TRUE, n=20, theme="blue")
 
 
